#!/usr/bin/env python

import random
import paho.mqtt.client as mqtt
import json
from rich.console import Console

host = "192.168.1.6"
port = 1883
inTopic =  'ChallengerRP2040/out'
outTopic = 'ChallengerRP2040/in'
client = "ChallengerRP2040ColorProvider"

console = Console(color_system="truecolor")

def on_connect(client, userdata, flags, rc):
    console.print("connected...", style="bold")
    client.subscribe(inTopic)

def on_message(client, userdata, msg):
    console.print("Incoming message")
    data = json.loads(msg.payload)
    console.print(data, style="italic")
    if data["command"] == "getRandomColor":
        console.print("Generate color response")
        r = random.randrange(0, 16)  # Limit to 16 instead of 256, otherwise the LED is too bright
        g = random.randrange(0, 16)
        b = random.randrange(0, 16)
        color="rgb({},{},{})".format(r*16, g*16, b*16)  # But scale up luminance for terminal
        console.print(color, end='')
        console.print(" \u25CF", style=color)
        data = json.dumps(
            {
                'r': r,
                'g': g,
                'b': b
            }
        )
        client.publish(outTopic, data)


client = mqtt.Client(client)
client.on_connect = on_connect
client.on_message = on_message
client.connect(host, port)
client.loop_forever()